@@ -1,7 +1,6 @@
 # Copyright 2015-2017 Laszlo Attila Toth
 # Distributed under the terms of the GNU Lesser General Public License v3
 
-import collections
 import typing
 
 from dewi_core.command import Command
@@ -13,10 +12,7 @@ class Plugin:
     A plugin is an extension of DEWI.
     """
 
-    def get_description(self) -> str:
-        raise NotImplementedError
-
-    def get_dependencies(self) -> collections.Iterable:
+    def get_dependencies(self) -> typing.Iterable[str]:
         return ()
 
     def load(self, c: Context):
@@ -33,8 +29,7 @@ class Plugin:
         >>
         >>
         >>  class SamplePlugin(Plugin):
-        >>      def get_description(self) -> str:
-        >>          return 'Provides "sample" command'
+        >>      '''Provides "sample" command'''
         >>
         >>      def load(self, c: Context):
         >>          self._r(c, SampleCommand)
